@@ -28,16 +28,12 @@ def qc_supp(yaml_dict, pro_dir , odir):
         shutil.rmtree(qc_dir_new)
     os.makedirs(qc_dir_new)
 
-    qc_stat = open(os.path.join(qc_dir_new, "qc.stat.xls"), "w")
-    qc_stat.write("\t".join(["Sample", "Raw Reads", "Raw Bases(G)", "Raw Q20(%)", "Raw Q30(%)", "Raw GC(%)", 
-        "Clean Reads", "Clean Bases(G)", "Clean Q20(%)", "Clean Q30(%)", "Clean GC(%)", "Effective Rate(%)"]) + "\n")
+    os.system('ln -srf %s %s' %(os.path.join(pro_dir,"QC","qc.stat.xls") , os.path.join(qc_dir_new,"QC")))
 
     for sample in yaml_dict["samples"]:
         raw_dir = os.path.join(pro_dir, "QC", sample)
         res_dir = os.path.join(qc_dir_new,sample)
         os.makedirs(res_dir)
-        raw_qc_stat = os.path.join(raw_dir, "%s.qc.stat.xls" %(sample))
-        qc_stat.write(open(raw_qc_stat).readlines()[1])
         reads_filter = os.path.join(raw_dir, "%s.reads.filter"%(sample))
         link_pics(reads_filter, res_dir)
         base_qual = os.path.join(raw_dir, "%s.bases.quality"%(sample))
@@ -46,7 +42,6 @@ def qc_supp(yaml_dict, pro_dir , odir):
         link_pics(base_dis, res_dir)
         gc_dis = os.path.join(raw_dir, "%s.GC.distribution"%(sample))
         link_pics(gc_dis, res_dir)
-    qc_stat.close()
 
 def uid_supp(prodir, odir):
     """Summarize UID stat for report generation
